ahbicht.expressions.ahb\_expression\_evaluation module
======================================================

.. automodule:: ahbicht.expressions.ahb_expression_evaluation
   :members:
   :undoc-members:
   :show-inheritance:
